Description: PyPI - Version PyPI - Python Version Test DOI Documentation Status A lean and kind Open Microscopy Environment (OME) Next Generation File Format (NGFF) Zarr implementation, OME-Zarr. ✨ Features: Mi...

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# ngff-zarr

A lean and kind Open Microscopy Environment (OME) Next Generation File Format (NGFF) Zarr implementation, OME-Zarr.

## ✨ Features

- Minimal dependencies

- Work with arbitrary Zarr store types

- Lazy, parallel, and web ready – no local filesystem required

- Process extremely large datasets

- Multiple downscaling methods

- Supports Python>=3.8

- Implements version 0.4 of the OME-Zarr NGFF specification

- 👋 Quick start
  - Installation
  - Command line conversion
  - NumPy array to OME-Zarr
- 💾 Installation
- 🐍 Python Array API
  - Array to NGFF Image
  - Generate multiscales
  - Write to Zarr
- 👨‍💻 Command Line Interface
  - Installation
  - Usage
- ⚕️ Insight Toolkit (ITK)
  - ITK Python
  - ITK-Wasm Python
- 🔖 Methods
  - `ITKWASM_GAUSSIAN`
  - `ITKWASM_BIN_SHRINK`
  - `ITKWASM_LABEL_IMAGE`
  - `ITK_GAUSSIAN`
  - `ITK_BIN_SHRINK`
  - `DASK_IMAGE_GAUSSIAN`
  - `DASK_IMAGE_MODE`
  - `DASK_IMAGE_NEAREST`
- 🔨 Development
  - Get the source code
  - Install dependencies
  - Run the test suite
  - Build the documentation
  - Update test data
  - Submit the patch

📖 Reference

- API Reference
  - `ngff_zarr`
    - Subpackages
    - Submodules
    - Package Contents